/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.aggregation;

import java.util.List;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;
import org.springframework.data.mongodb.core.convert.MongoCustomConversions;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;
import com.fasterxml.jackson.datatype.jsr310.JavaTimeModule;

import de.ozgcloud.aggregation.warehouse.DocumentToJsonNodeConverter;
import de.ozgcloud.aggregation.warehouse.JsonNodeToDocumentConverter;

@Configuration
public class ConverterConfiguration {

	@Bean
	ObjectMapper objectMapper() {
		var objectMapper = new ObjectMapper().registerModules(new JavaTimeModule());
		objectMapper.configure(SerializationFeature.WRITE_DATES_AS_TIMESTAMPS, false);
		objectMapper.configure(SerializationFeature.WRITE_DATES_WITH_ZONE_ID, true);
		return objectMapper;
	}

	@Bean
	JsonNodeToDocumentConverter j2dConverter(ObjectMapper mapper) {
		return new JsonNodeToDocumentConverter(mapper);
	}

	@Bean
	DocumentToJsonNodeConverter d2jConverter(ObjectMapper mapper) {
		return new DocumentToJsonNodeConverter(mapper);
	}

	@Bean
	@Primary
	MongoCustomConversions getMongoCustomConversions(JsonNodeToDocumentConverter j2dConverter, DocumentToJsonNodeConverter d2jConverter) {
		return new MongoCustomConversions(List.of(
				j2dConverter,
				d2jConverter,
				new ZonedDateTimeReadConverter(),
				new ZonedDateTimeWriteConverter()));
	}

}
