/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.aggregation.warehouse;

import org.bson.Document;
import org.springframework.core.convert.ConversionException;
import org.springframework.core.convert.converter.Converter;
import org.springframework.data.convert.ReadingConverter;
import org.springframework.stereotype.Component;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.node.ObjectNode;

import lombok.RequiredArgsConstructor;

@Component
@ReadingConverter
@RequiredArgsConstructor
/**
 * The {@link DocumentToJsonNodeConverter} converts {@link Document}s to
 * {@link ObjectNode}s
 */
public class DocumentToJsonNodeConverter implements Converter<Document, ObjectNode> {

	private final ObjectMapper jacksonObjectMapper;

	@Override
	public ObjectNode convert(Document source) {
		try {
			return (ObjectNode) jacksonObjectMapper.readTree(source.toJson());
		} catch (JsonProcessingException e) {
			throw new JsonConversionException("Unable to convert document to json node", e);
		}
	}

	private static class JsonConversionException extends ConversionException {

		private static final long serialVersionUID = 1L;

		public JsonConversionException(String message, Throwable cause) {
			super(message, cause);
		}

	}

}