/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.aggregation.transformation;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;

import de.ozgcloud.aggregation.warehouse.DocumentEntry;
import de.ozgcloud.aggregation.warehouse.DocumentEntryTestFactory;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangStubTestFactory;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangTestFactory;

public class VorgangMapperTest {

	@InjectMocks
	private final VorgangMapper mapper = Mappers.getMapper(VorgangMapper.class);

	@Nested
	class TestToDocumentEntry {

		@Test
		void shouldMapToDocumentEntry() {
			var expectedEntry = DocumentEntryTestFactory.createBuilder().payload(null).build();

			var documentEntry = mapper.toDocumentEntryBuilder(OzgCloudVorgangTestFactory.create(), DocumentEntry.builder());

			assertThat(documentEntry).usingRecursiveComparison().isEqualTo(expectedEntry);
		}
	}

	@Nested
	class TestFromVorgangStub {

		@Test
		void shouldMapAllFieldsButEingangs() {
			var expected = OzgCloudVorgangTestFactory.createBuilder()
					.clearEingangs()
					.build();

			var mapped = mapper.fromVorgangStub(OzgCloudVorgangStubTestFactory.create());

			assertThat(mapped).usingRecursiveComparison().isEqualTo(expected);
		}
	}
}
